@@ -49,6 +49,7 @@ class SASconfigHTTP:
 
       self._token    = cfg.get('authtoken', None)
       self.url       = cfg.get('url', '')
+      self.serverid  = cfg.get('serverid', None)
       self.ip        = cfg.get('ip', '')
       self.port      = cfg.get('port', None)
       self.ctxname   = cfg.get('context', '')
@@ -98,6 +99,13 @@ class SASconfigHTTP:
          else:
             self.url = inurl
 
+      insid = kwargs.get('serverid', None)
+      if insid is not None:
+         if lock and self.serverid:
+            print("Parameter 'serverid' passed to SAS_session was ignored due to configuration restriction.")
+         else:
+            self.serverid = insid
+
       inip = kwargs.get('ip', None)
       if inip is not None:
          if lock and len(self.ip):
@@ -236,7 +244,7 @@ class SASconfigHTTP:
          else:
             self.port = 80
 
-      if not self._token and not authcode and not jwt:
+      if not self._token and not authcode and not jwt and not self.serverid:
          found = False
          if self.authkey:
             if os.name == 'nt':
@@ -315,6 +323,7 @@ class SASconfigHTTP:
                   self._token = None
                   raise RuntimeError("No password provided.")
 
+      # get AuthToken
       if self.ssl:
          if self.verify:
             # handle having self signed certificate default on Viya w/out copies on client; still ssl, just not verifyable
@@ -347,75 +356,82 @@ class SASconfigHTTP:
          self._token = None
          raise SASHTTPconnectionError(msg="No Contexts found on Compute Service at ip="+self.ip)
 
-      ctxnames = []
-      for i in range(len(contexts)):
-         ctxnames.append(contexts[i].get('name'))
+      if not self.serverid:
+         ctxnames = []
+         for i in range(len(contexts)):
+            ctxnames.append(contexts[i].get('name'))
 
-      if len(ctxnames) == 0:
-         self._token = None
-         raise SASHTTPconnectionError(msg="No Contexts found on Compute Service at ip="+self.ip)
+         if len(ctxnames) == 0:
+            self._token = None
+            raise SASHTTPconnectionError(msg="No Contexts found on Compute Service at ip="+self.ip)
 
-      if len(self.ctxname) == 0:
-         if len(ctxnames) == 1:
-            self.ctxname = ctxnames[0]
-            logger.info("Using SAS Context: " + self.ctxname)
-         else:
-            try:
-               ctxname = self._prompt("Please enter the SAS Context you wish to run. Available contexts are: " +
-                                      str(ctxnames)+" ")
-               if ctxname is None:
-                  self._token = None
-                  raise RuntimeError("No SAS Context provided.")
-               else:
-                  self.ctxname = ctxname
-            except:
-               raise SASHTTPconnectionError(msg=
-                  "SAS Context specified '"+self.ctxname+"' was not found. Prompting failed. Available contexts were: " +
-                   str(ctxnames)+" ")
-
-      while self.ctxname not in ctxnames:
-         if not lock:
-            '''    this was original code before compute was production. users can't create these on the fly.
-            createctx = self._prompt(
-                "SAS Context specified was not found. Do you want to create a new context named "+self.ctxname+" [Yes|No]?")
-            if createctx.upper() in ('YES', 'Y'):
-               contexts = self._create_context(user)
+         if len(self.ctxname) == 0:
+            if len(ctxnames) == 1:
+               self.ctxname = ctxnames[0]
+               logger.info("Using SAS Context: " + self.ctxname)
             else:
-            '''
-            try:
-               ctxname = self._prompt(
-                   "SAS Context specified was not found. Please enter the SAS Context you wish to run. Available contexts are: " +
-                    str(ctxnames)+" ")
-               if ctxname is None:
-                  self._token = None
+               try:
+                  ctxname = self._prompt("Please enter the SAS Context you wish to run. Available contexts are: " +
+                                         str(ctxnames)+" ")
+                  if ctxname is None:
+                     self._token = None
+                     raise RuntimeError("No SAS Context provided.")
+                  else:
+                     self.ctxname = ctxname
+               except:
+                  raise SASHTTPconnectionError(msg=
+                     "SAS Context specified '"+self.ctxname+"' was not found. Prompting failed. Available contexts were: " +
+                      str(ctxnames)+" ")
+
+         while self.ctxname not in ctxnames:
+            if not lock:
+               '''    this was original code before compute was production. users can't create these on the fly.
+               createctx = self._prompt(
+                   "SAS Context specified was not found. Do you want to create a new context named "+self.ctxname+" [Yes|No]?")
+               if createctx.upper() in ('YES', 'Y'):
+                  contexts = self._create_context(user)
+               else:
+               '''
+               try:
+                  ctxname = self._prompt(
+                      "SAS Context specified was not found. Please enter the SAS Context you wish to run. Available contexts are: " +
+                       str(ctxnames)+" ")
+                  if ctxname is None:
+                     self._token = None
+                     raise SASHTTPconnectionError(msg=
+                         "SAS Context specified '"+self.ctxname+"' was not found. Prompting failed. Available contexts were: " +
+                          str(ctxnames)+" ")
+                  else:
+                     self.ctxname = ctxname
+               except:
                   raise SASHTTPconnectionError(msg=
                       "SAS Context specified '"+self.ctxname+"' was not found. Prompting failed. Available contexts were: " +
                        str(ctxnames)+" ")
-               else:
-                  self.ctxname = ctxname
-            except:
-               raise SASHTTPconnectionError(msg=
-                   "SAS Context specified '"+self.ctxname+"' was not found. Prompting failed. Available contexts were: " +
-                    str(ctxnames)+" ")
-         else:
-            msg  = "SAS Context specified in the SASconfig ("+self.ctxname+") was not found on this server, and because "
-            msg += "the SASconfig is in lockdown mode, there is no prompting for other contexts. No connection established."
-            logger.error(msg)
-            self._token = None
-            raise RuntimeError("No SAS Context provided.")
+            else:
+               msg  = "SAS Context specified in the SASconfig ("+self.ctxname+") was not found on this server, and because "
+               msg += "the SASconfig is in lockdown mode, there is no prompting for other contexts. No connection established."
+               logger.error(msg)
+               self._token = None
+               raise RuntimeError("No SAS Context provided.")
 
-      for i in range(len(contexts)):
-         if contexts[i].get('name') == self.ctxname:
-            self.ctx = contexts[i]
-            break
+         for i in range(len(contexts)):
+            if contexts[i].get('name') == self.ctxname:
+               self.ctx = contexts[i]
+               break
 
-      if self.ctx == {}:
-         raise SASHTTPconnectionError(msg="No context information returned for context {}\n{}".format(self.ctxname, contexts))
+         if self.ctx == {}:
+            raise SASHTTPconnectionError(msg="No context information returned for context {}\n{}".format(self.ctxname, contexts))
+      else:
+         self.ctx = contexts
+         self.ctxname = 'tom'
 
-      return
+         return
 
    def _authenticate(self, user, pw, authcode, client_id, client_secret, jwt):
-      #import pdb; pdb.set_trace()
+
+      if self.serverid:
+         return 'tom'
+
       if   authcode:
          uauthcode      = urllib.parse.quote(authcode)
          uclient_id     = urllib.parse.quote(client_id)
@@ -469,21 +485,35 @@ class SASconfigHTTP:
 
       # GET Contexts
       conn = self.HTTPConn; conn.connect()
-      headers={"Accept":"application/vnd.sas.collection+json",
-               "Accept-Item":"application/vnd.sas.compute.context.summary+json",
-               "Authorization":"Bearer "+self._token}
-      conn.request('GET', "/compute/contexts?limit=999999", headers=headers)
+
+      if not self.serverid:
+         headers={"Accept":"application/vnd.sas.collection+json",
+                  "Accept-Item":"application/vnd.sas.compute.context.summary+json",
+                  "Authorization":"Bearer "+self._token}
+         conn.request('GET', "/compute/contexts?limit=999999", headers=headers)
+      else:
+         headers={"Accept":"*/*",
+                  "Accept-Item":"application/vnd.sas.compute.context.summary+json",
+                  "Authorization":"Bearer "+self._token}
+         conn.request('GET', "/compute/servers/"+self.serverid, headers=headers)
+
       req = conn.getresponse()
       status = req.status
       resp = req.read()
       conn.close()
 
       if status > 299:
-         fmsg = "Failure in GET Contexts. Status="+str(status)+"\nResponse="+resp.decode(self.encoding)
+         if not self.serverid:
+            fmsg = "Failure in GET Contexts. Status="+str(status)+"\nResponse="+resp.decode(self.encoding)
+         else:
+            fmsg = "Failure in GET Server. Status="+str(status)+"\nResponse="+resp.decode(self.encoding)
          raise SASHTTPconnectionError(msg=fmsg)
 
       js = json.loads(resp.decode(self.encoding))
-      contexts = js.get('items')
+      if not self.serverid:
+         contexts = js.get('items')
+      else:
+         contexts = js
 
       return contexts
 
@@ -1336,23 +1366,12 @@ class SASsessionHTTP():
       if encode_errors is None:
          encode_errors = 'fail'
 
-      bpc = self._sb.pyenc[0]
-      if char_lengths and str(char_lengths).strip() in ['1','2','3','4']:
-         bpc = int(char_lengths)
-      if char_lengths and str(char_lengths) == 'exact':
-         CnotB = False
-      else:
-         CnotB = bpc == 1
+      CnotB = kwargs.pop('CnotB', None)
 
-      if type(char_lengths) is not dict or len(char_lengths) < ncols:
-         charlens = self._sb.df_char_lengths(df, encode_errors, char_lengths)
-      else:
-         charlens = char_lengths
-
-      if charlens is None:
+      if char_lengths is None:
          return -1
 
-      chr_upper = {k.upper():v for k,v in charlens.items()}
+      chr_upper = {k.upper():v for k,v in char_lengths.items()}
 
       if type(df.index) != pd.RangeIndex:
          warnings.warn("Note that Indexes are not transferred over as columns. Only actual columns are transferred")
@@ -1360,7 +1379,7 @@ class SASsessionHTTP():
       for name in df.columns:
          colname = str(name).replace("'", "''")
          col_up  = str(name).upper()
-         input  += "'"+colname+"'n "
+         input  += "input '"+colname+"'n "
          if col_up in lab_keys:
             label += "label '"+colname+"'n ="+lab_upper[col_up]+";\n"
          if col_up in fmt_keys:
@@ -1406,6 +1425,7 @@ class SASsessionHTTP():
                   dts.append('B')
                else:
                   dts.append('N')
+         input += ";\n"
 
       code = "data "
       if len(libref):
@@ -1425,8 +1445,13 @@ class SASsessionHTTP():
       if len(format):
          code += "format "+format+";\n"
       code += label
-      code += "infile datalines delimiter="+delim+" STOPOVER;\ninput @;\nif _infile_ = '' then delete;\ninput "+input+";\n"+xlate+";\ndatalines4;"
-      self._asubmit(code, "text")
+      code += "infile datalines delimiter="+delim+" STOPOVER;\n"
+      code += "input @;\nif _infile_ = '' then delete;\nelse do;\n"
+      code +=  input+xlate+";\n"
+      code += "end;\n"
+      code += "datalines4;"
+      jobid = self._asubmit(code, "text")
+      self._log += self._getlog(jobid).replace(chr(12), chr(10))
 
       blksz = int(kwargs.get('blocksize', 1000000))
       noencode = self._sb.sascei == 'utf-8' or encode_errors == 'ignore'
@@ -1442,7 +1467,7 @@ class SASsessionHTTP():
                var = '.'
             elif dts[col] == 'C':
                if var == 'nan' or len(var) == 0:
-                  var = ' '
+                  var = ' '+colsep
                else:
                   var = var.replace(colsep, colrep)
             elif dts[col] == 'B':
@@ -1453,15 +1478,13 @@ class SASsessionHTTP():
                else:
                   var = str(row[col].to_datetime64())[:26]
 
-            card += var
-            if col < (ncols-1):
-               card += colsep
+            if embedded_newlines:
+               var = var.replace(LF, colrep).replace(CR, colrep)
+               var = var.replace('\n', LF).replace('\r', CR)
 
-         if embedded_newlines:
-            card = card.replace(LF, colrep).replace(CR, colrep)
-            card = card.replace('\n', LF).replace('\r', CR)
+            card += var+"\n"
 
-         code += card+"\n"
+         code += card
 
          if len(code) > blksz:
             if not noencode:
@@ -1478,7 +1501,8 @@ class SASsessionHTTP():
                else:
                   code = code.encode(self.sascfg.encoding, errors='replace').decode(self.sascfg.encoding)
 
-            self._asubmit(code, "text")
+            jobid = self._asubmit(code, "text")
+            self._log += self._getlog(jobid).replace(chr(12), chr(10))
             code = ""
 
       if not noencode and len(code) > 0:
@@ -1495,7 +1519,8 @@ class SASsessionHTTP():
          else:
             code = code.encode(self.sascfg.encoding, errors='replace').decode(self.sascfg.encoding)
 
-      self._asubmit(code+";;;;\n;;;;", "text")
+      jobid = self._asubmit(code+";;;;\n;;;;", "text")
+      self._log += self._getlog(jobid).replace(chr(12), chr(10))
       ll = self.submit("quit;", 'text')
       return None
 
@@ -1729,9 +1754,23 @@ class SASsessionHTTP():
          tabname = "'"+table.strip().replace("'", "''")+"'n "
 
       code  = "data work.sasdata2dataframe / view=work.sasdata2dataframe; set "+tabname+self._sb._dsopts(dsopts)+";run;\n"
+      code += "data _null_; file LOG; d = open('work.sasdata2dataframe');\n"
+      code += "lrecl = attrn(d, 'LRECL');\n"
+      code += "lr='LRECL=';\n"
+      code += "put lr lrecl;\n"
+      code += "run;"
 
       ll = self.submit(code, "text")
 
+      try:
+         l2 = ll['LOG'].rpartition("LRECL= ")
+         l2 = l2[2].partition("\n")
+         lrecl = int(l2[0])
+      except Exception as e:
+         logger.error("Invalid output produced durring sasdata2dataframe step. Step failed.\
+         \nPrinting the error: {}\nPrinting the SASLOG as diagnostic\n{}".format(str(e), ll['LOG']))
+         return None
+
       ##GET Data Table Info
       #conn = self.sascfg.HTTPConn; conn.connect()
       #headers={"Accept":"application/vnd.sas.compute.data.table+json", "Authorization":"Bearer "+self.sascfg._token}
@@ -1827,8 +1866,10 @@ class SASsessionHTTP():
                if i % 10 == 9:
                   code +='\n'
 
+      lreclx = max(self.sascfg.lrecl, (lrecl + nvars + 1))
+
       miss  = {}
-      code += "\nfile _tomodsx lrecl="+str(self.sascfg.lrecl)+" dlm="+cdelim+" recfm=v termstr=NL encoding='utf-8';\n"
+      code += "\nfile _tomodsx lrecl="+str(lreclx)+" dlm="+cdelim+" recfm=v termstr=NL encoding='utf-8';\n"
       for i in range(nvars):
          if vartype[i] != 'FLOAT':
             code += "'"+varlist[i]+"'n = translate('"
