@@ -564,50 +564,59 @@ Will use HTML5 for this SASsession.""")
    def _endsas(self):
       rc = 0
       if self.pid:
-         self.stdin[0].send(b'\ntom says EOL=ENDSAS                          \n')
-         if os.name == 'nt':
-            pid = self.pid.pid
-            try:
-               rc = self.pid.wait(5)
-               self.pid = None
-            except (subprocess.TimeoutExpired):
-               if self.sascfg.verbose:
-                  logger.info("SAS didn't shutdown w/in 5 seconds; killing it to be sure")
-               self.pid.kill()
-         else:
-            pid = self.pid
-            x = 5
-            while True:
-               rc = os.waitpid(self.pid, os.WNOHANG)
-               if rc[0] != 0:
-                  break
-               x = x - 1
-               if x < 1:
-                  break
-               sleep(1)
-
-            if rc[0] != 0:
-               pass
+         try: # More Mac OS Python issues that don't work like everywhere else
+            self.stdin[0].send(b'\ntom says EOL=ENDSAS                          \n')
+            if os.name == 'nt':
+               try:
+                  rc = self.pid.wait(5)
+                  self.pid = None
+               except (subprocess.TimeoutExpired):
+                  if self.sascfg.verbose:
+                     logger.info("SAS didn't shutdown w/in 5 seconds; killing it to be sure")
+                  self.pid.kill()
             else:
-               if self.sascfg.verbose:
-                  logger.info("SAS didn't shutdown w/in 5 seconds; killing it to be sure")
-               os.kill(self.pid, signal.SIGKILL)
+               x = 5
+               while True:
+                  rc = os.waitpid(self.pid, os.WNOHANG)
+                  if rc[0] != 0:
+                     break
+                  x = x - 1
+                  if x < 1:
+                     break
+                  sleep(1)
 
+               if rc[0] != 0:
+                  pass
+               else:
+                  if self.sascfg.verbose:
+                     logger.info("SAS didn't shutdown w/in 5 seconds; killing it to be sure")
+                  os.kill(self.pid, signal.SIGKILL)
+         except:
+            pass
 
-         self.stdin[0].shutdown(socks.SHUT_RDWR)
+         try: # Mac OS Python has bugs with this call
+            self.stdin[0].shutdown(socks.SHUT_RDWR)
+         except:
+            pass
          self.stdin[0].close()
          self.sockin.close()
 
-         self.stdout[0].shutdown(socks.SHUT_RDWR)
+         try: # Mac OS Python has bugs with this call
+            self.stdout[0].shutdown(socks.SHUT_RDWR)
+         except:
+            pass
          self.stdout[0].close()
          self.sockout.close()
 
-         self.stderr[0].shutdown(socks.SHUT_RDWR)
+         try: # Mac OS Python has bugs with this call
+            self.stderr[0].shutdown(socks.SHUT_RDWR)
+         except:
+            pass
          self.stderr[0].close()
          self.sockerr.close()
 
          if self.sascfg.verbose:
-            logger.info("SAS Connection terminated. Subprocess id was "+str(pid))
+            logger.info("SAS Connection terminated. Subprocess id was "+str(self.pid if os.name != 'nt' else self.pid.pid))
          self.pid        = None
          self._sb.SASpid = None
       return
