@@ -237,7 +237,7 @@ public class saspy2j
                      {
                      flen = Long.valueOf(pgm.substring(0, idx));
                      pgm  = pgm.substring(idx + 13 + 33);
-               
+
                      bstr = null;
                      try
                         {
@@ -255,7 +255,7 @@ public class saspy2j
                         }
                      catch (GenericError e)
                         {}
-               
+
                      if (! (bstr == null))
                         {
                         while (flen > 0)
@@ -269,28 +269,14 @@ public class saspy2j
                                  bstr.Write(java.util.Arrays.copyOfRange(out, 0, slen));
                                  }
                               }
-                           catch (org.omg.CORBA.COMM_FAILURE e)
-                              {
-                              if (reconnect)
-                                 {
-                                 ods = true;
-                                 connect(true, true, false);
-                                 bstr = fileref.OpenBinaryStream(StreamOpenMode.StreamOpenModeForWriting);
-                                 bstr.Write(odsdata.value);
-                                 }
-                              else
-                                 {
-                                 String msg = "We failed in Submit\n"+e.getMessage();
-                                 errp.write(msg);
-                                 errp.flush();
-                                 System.out.print(msg);
-                                 e.printStackTrace();
-                                 throw new IOException();
-                                 }
-                              }
                            catch (Exception e)
                               {
-                              slen = 0; 
+                              String msg = "We failed in Submit\n"+e.getMessage();
+                              errp.write(msg);
+                              errp.flush();
+                              System.out.print(msg);
+                              e.printStackTrace();
+                              throw new IOException();
                               }
                            }
                         bstr.Close();
@@ -299,7 +285,7 @@ public class saspy2j
                   else if (eol.contains("DNLOAD"))
                      {
                      pgm  = pgm.substring(idx + 13 + 33);
-               
+
                      bstr = null;
                      try
                         {
@@ -336,28 +322,14 @@ public class saspy2j
                                  odsout.flush();
                                  }
                               }
-                           catch (org.omg.CORBA.COMM_FAILURE e)
-                              {
-                              if (reconnect)
-                                 {
-                                 ods = true;
-                                 connect(true, true, false);
-                                 bstr = fileref.OpenBinaryStream(StreamOpenMode.StreamOpenModeForReading);
-                                 bstr.Read(blen, odsdata);
-                                 }
-                              else
-                                 {
-                                 String msg = "We failed in Submit\n"+e.getMessage();
-                                 errp.write(msg);
-                                 errp.flush();
-                                 System.out.print(msg);
-                                 e.printStackTrace();
-                                 throw new IOException();
-                                 }
-                              }
                            catch (Exception e)
                               {
-                              slen = 0; 
+                              String msg = "We failed in Submit\n"+e.getMessage();
+                              errp.write(msg);
+                              errp.flush();
+                              System.out.print(msg);
+                              e.printStackTrace();
+                              throw new IOException();
                               }
                            }
                         bstr.Close();
@@ -367,7 +339,19 @@ public class saspy2j
                      {
                      try
                         {
-                        lang.Submit(pgm.substring(0, idx));
+                        try
+                           {
+                           lang.Submit(pgm.substring(0, idx));
+                           }
+                        catch (Exception e)
+                           {
+                           String msg = "We failed in Submit\n"+e.getMessage()+"END We failed in Submit\n";
+                           errp.write(msg);
+                           errp.flush();
+                           System.out.print(msg);
+                           e.printStackTrace();
+                           //throw new IOException();
+                           }
                         pgm = pgm.substring(idx + 13 + 33);
                         }
                      catch (org.omg.CORBA.COMM_FAILURE e)
@@ -431,15 +415,15 @@ public class saspy2j
                               cx.close();
                               server     = (BridgeServer) Server.fromURI(uri);
                               ad         = server.getDomain();
-                    
+
                               if (appName != "")
                                  server.setServerName(appName.replace("\'", ""));
                               server.setOption(SASURI.applicationNameKey, "SASPy");
-                              
+
                               cxfConfig  = new ManualConnectionFactoryConfiguration(server);
                               cxfManager = new ConnectionFactoryManager();
                               cxf        = cxfManager.getFactory(cxfConfig);
-                              
+
                               if (spn)
                                  cx = cxf.getConnection(cred);
                               else
@@ -471,7 +455,19 @@ public class saspy2j
                      {
                      pgm = pgm.substring(0, idx);
                      try{
-                        lang.Submit(pgm);
+                        try
+                           {
+                           lang.Submit(pgm);
+                           }
+                        catch (Exception e)
+                           {
+                           String msg = "We failed in Submit\n"+e.getMessage();
+                           errp.write(msg);
+                           errp.flush();
+                           System.out.print(msg);
+                           e.printStackTrace();
+                           //throw new IOException();
+                           }
                         if (undo)
                            lang.Submit("\nproc printto;run;\n%put "+eol.substring(1)+";\n");
                         else
@@ -733,11 +729,11 @@ private static void connect(boolean recon, boolean ods, boolean zero) throws IOE
              if (appName != "")
                 server.setServerName(appName.replace("\'", ""));
              server.setOption(SASURI.applicationNameKey, "SASPy");
-   
+
              cxfConfig  = new ManualConnectionFactoryConfiguration(server);
              cxfManager = new ConnectionFactoryManager();
              cxf        = cxfManager.getFactory(cxfConfig);
-   
+
              if (spn)
                 cx = cxf.getConnection(cred);
              else if (timeout > 0)
@@ -765,14 +761,14 @@ private static void connect(boolean recon, boolean ods, boolean zero) throws IOE
                 if (appName != "")
                    server.setServerName(appName.replace("\'", ""));
                 server.setOption(SASURI.applicationNameKey, "SASPy");
-   
+
                 if (spn)
                    server.setSecurityPackage(Server.SECURITY_PACKAGE_NEGOTIATE);
-   
+
                 cxfConfig  = new ManualConnectionFactoryConfiguration(server);
                 cxfManager = new ConnectionFactoryManager();
                 cxf        = cxfManager.getFactory(cxfConfig);
-   
+
                 if (spn)
                    {
                    cred = SecurityPackageCredential.getInstance();
@@ -862,3 +858,4 @@ private static void connect(boolean recon, boolean ods, boolean zero) throws IOE
        }
    }
 }
+
